# Changelog

## 0.1.0-alpha.1 (2025-05-23)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/cruzluna/sps-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** api update ([cc10265](https://github.com/cruzluna/sps-python/commit/cc102657eb5ccedc08e62f7ac414cdb189d5f4dd))
* **api:** manual updates to openapi.stainless.yml ([a033c93](https://github.com/cruzluna/sps-python/commit/a033c935ff5ee59dc914d808324b45db44cbacfa))

## 0.0.1-alpha.1 (2025-05-23)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/cruzluna/sps-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* configure new SDK language ([b6faf00](https://github.com/cruzluna/sps-python/commit/b6faf005252c440af7e40e22da9498f36154548f))
* update SDK settings ([9d11cbd](https://github.com/cruzluna/sps-python/commit/9d11cbdcb5e0f10112515e48db56fea1cc9118de))
* update SDK settings ([48b1f52](https://github.com/cruzluna/sps-python/commit/48b1f52463b2de15053b7d6a4a063f87b67a3e1c))
